# Argon Laser-Sustianed Plasma High-speed Video Footage
This directory contains the following data:
- ~~`.avi` and `.cihx` files of high-speed experimental footage~~
- A spreadsheet of successful Laser-Sustained Plasma (LSP) ignition tests `shotlist.xlsx`
- A dimensional reference `.bmp` picture

**No video data is available in this version of the dataset. Please download the full version of the dataset to access the high-speed footage.**


## ~~Footage~~
~~The high-speed footage is split in two groups:~~
1. ~~Successful LSP ignitions, labelled according to the standard naming convention and saved in the same location as this README~~
2. ~~Successful LSP ignitions performed before the naming convention was used, saved under the `_SPX Shots` directory~~

~~Each video is saved under its own subdirectory. Videos in the `.avi` format can be watched on most media players. Each video is accompanied by a `.cihx` file that can only be opened with the PFV4 software used to interface with the high-speed camera. This software is distributed for free by Photron. The `.cihx` files contain useful metadata and provide an interface for PFV4, which provides several tools to analyze and post-process footage.~~

~~All footage was captured using a Photron Fastcam SA5~~


## Shotlist
The `shotlist.xlsx` Excel file contains information on every successful LSP test (often referred to as "shot"). This file is read by the data processing code written for this thesis project. Specifically, the `datamanager.py` module reads the shotlist and provides an interface for all other scripts to pull data from the shotlist, such as experimental parameters and/or results. It is thus **heavily discouraged** to rename, move, or delete this file.

### Methodological information
The shotlist data was entered manually for each successful laser-sustained plasma experiment. It is also used to semi-automatically assign a unique identifier code for each trial.

### Data-specific information
The table headings include a unit where applicable and are described below:
- **Index**: The index of the shot. Unique to each shot and increments by 1 for each shot.
- **Series Prefix**: An alphabetic code identifying a group of shots which share some experimental parameters or goals. Each prefix is described in the "Information" sheet of the spreadsheet.
- **Series Index**: The index of the shot within its series.
- **Date**: The date of the shot in ISO-8601 format, i.e., YYYY-MM-DD.
- **Laser Setpoint***: The percentage setpoint used for the laser emission. 
- **Mode**: The laser mode. `RP` for pulse or `CW` for continuous.
- **Pulse Width***: The pulse duration rounded to the nearest ms.
- **Pulse Spec**: The identifier for the specific pulse shape used for the test. `Constant` means a constant-power pulse.
- **Gas**: working gas used in the shot.
- **Pressure**: The static pressure set in the test section.
- **Focal Length**: Focal length of the laser optics.
- **Ignition Type**: The method of ignition.
- **Stable**: Whether the LSP remained active throughout the entire duration of the laser emission.
- **Electrode Distance**: For spark-ignited tests, the distance between the igniter's electrodes.
- **Output Energy**: The measured laser-pulse energy transmitted through the LSP and reaching the power meter.
- **Oscilloscope Data**: The file number of the laser emission state and pressure data exported by the oscilloscope. As two files are usually generated, the number refers to the first file (laser emission state) and implies the second file (pressure data) number is incremented by one. If two numbers are specified, they refer to the laser emission state file and pressure data file, respectively. In theory, these data have already been organized in their respective directories.
- **Aperture**: The numerical aperture of the high-speed camera's lens.
- **ND**: The ND number of the variable ND filter.
- **Nozzle Diameter**: The diameter of the orifice nozzle. Left blank for static tests.
- **Notes**: Additional notes. Contains the file/folder name for the high-speed footage is the shot does not follow the identifier convention (i.e., `SPX`-series shots)

\* These laser parameters should not be used to determine the laser-pulse power or energy unless the **Pulse Spec** is `Constant`. For other pulses, refer to the `PulseDB.csv` file in the `../Pulse Shapes` directory, which gives pulse duration and energy data for each pulse spec.


## Dimensional reference
The dimensional reference file, `Dimensional_Reference.bmp`, is a photograph taken with the high-speed camera of a graduated card. This allows the calibration of the footage to measure objects located in the test section, such as the plasma dimensions. The longest graduations are spaced by 5 mm each. The intermediate length graduations are spaced by 1 mm, and the smallest graduations indicate each half-millimeter. Using this reference should result in a footage resolution of around 0.07 mm/px.

All shots in the main footage directory (i.e., not the `SPX` shots) were taken from approximately the same location and with the same focal length, so this dimensional reference is applicable to all the main LSP footage.


## Sharing and access information
All the data is shared under a CC BY 4.0 license. Please provide proper attribution by citing the dataset with your preferred citation style. For example:

Duplay, Emmanuel, Gabriel Dubé, and Siera Riel. “Argon Laser-Sustained Plasma Footage, Pressure Data, and Spectral Data.” 4TU.ResearchData, 2023. https://doi.org/10.4121/04ad8110-e3c4-4971-99ce-8a6c537166d6.


## Contact
Emmanuel Duplay  
emmanuel.duplay@gmail.com