# Laser Pulse Shape Data
Authors: Emmanuel Duplay, Gabriel Dubé, Siera Riel

This dataset is related to the following Master's thesis:

Duplay, Emmanuel. “Argon Laser-Plasma Thruster - Design and Test of a Laboratory Model.” M.Sc. Thesis, Delft University of Technology, 2024.


## Introduction
This dataset contains the laser pulse shapes used for laser-sustained plasma experiments. These pulse shapes all program *stepped pulses*, i.e., they all start at maximum power then step down to a lower constant power level. This stepped shape resembles an 'L', hence the following naming convention:

`[HighTime]L[LowSetpoint]_[PulseWidth]`

- `HighTime`: The duration for which the laser is at full power in ms, with a leading zero for durations less than 1 ms.
- `LowSetpoint`: The power setpoint in percent for the target power level.
- `PulseWidth`: Total pulse duration rounded to the nearest ms

This dataset also includes a database of all the pulses, tabulating detailed timings, power levels, and total pulse energy for each pulse shape.


## Methodological information
The pulse shape files are XML files with a `.shp` extensions, exported by the IPG Photonics PulseShaper software. These files are designed to be imported by the same software to program pulses in an IPG laser. However, as they are written in XML, they can easily be parsed by other software, such as the analysis code associated with this project.


## Data-specific information
Two data types are present in this set: pulse shapes and a pulse database.

### Pulse Shapes
The `.shp` files are written in XML, providing a series of time--power coordinates that can theoretically represent any arbitrary pulse shape. Each `<Point>` in the shape is defined with the following fields:
- `<N>` The index of the point
- `<Time>` The time coordinate in ms 
- `<Power>` The power setpoint coordinate in %

### Pulse Database
This CSV database summarizes detailed information on all pulse shapes, and is generated by the `Laser.util` python module included in the analysis code. It uses the following format:
- **Column 1**: Index used internally by the analysis code (the index for a `pandas.DataFrame`)
- **ID**: The pulse shape identifier
- **High SP**: The high setpoint power (decimal), usually 1.00.
- **Low SP**: The low setpoint power (decimal).
- **Duration**: The total pulse width in ms.
- **High duration**: The time in ms spent at the high setpoint power.
- **Low duration**: The time in ms spent at the low setpoint power.
- **Energy**: The computed energy in J of the laser pulse.

A copy of this database in saved as a `.pkl` Python pickle file, also exported by `pandas`. This is included to facilitate loading this database in a python script:
```python
import pandas as pd
database = pd.read_pickle(pulseDB.pkl)  # Returns a perfectly-parsed dataframe of pulseDB
```
This way, unlike with a `.csv` file, data types, delimiters, and other parameters do not need to be given when reading the data.


## Sharing and access information
All the data is shared under a CC BY 4.0 license. Please provide proper attribution by citing the dataset with your preferred citation style. For example:

Duplay, Emmanuel, Gabriel Dubé, and Siera Riel. “Argon Laser-Sustained Plasma Footage, Pressure Data, and Spectral Data.” 4TU.ResearchData, 2023. https://doi.org/10.4121/04ad8110-e3c4-4971-99ce-8a6c537166d6.


## Contact
Emmanuel Duplay  
emmanuel.duplay@gmail.com