# Argon Laser-Sustained Plasma ~~Footage~~, Pressure Data, and Spectral Data
Authors: Emmanuel Duplay, Gabriel Dubé, Siera Riel

This dataset is related to the following Master's thesis:

Duplay, Emmanuel. “Argon Laser-Plasma Thruster - Design and Test of a Laboratory Model.” M.Sc. Thesis, Delft University of Technology, 2024.

This is a general README that applies to all data in this dataset. More detailed READMEs for each group of data are available in their respective subdirectories.

This dataset is structured to be used with analysis code written for the above thesis and is available here:  
https://github.com/eeduplay/MScThesis (latest)  
https://doi.org/10.4121/04ad8110-e3c4-4971-99ce-8a6c537166d6 (archive)  
To function properly, the `DATAPATH` environment variable set in the code's `.env` file should be a full path pointing to the parent directory of this README.

**No video data is available in this version of the dataset. Please download the full version of the dataset to access the high-speed footage.**


## Introduction
This dataset contains high-speed video footage, pressure data, spectrograms, laser-pulse shape data, and a list of experimental trials on Laser-Sustained Plasma (LSP). These data subsets are divided using the following structure:
```
.
├── LSP/
│   ├── [DELETED] High-speed LSP footage
│   └── Database of all tests performed
├── Pressure Data/
│   └── Static pressure change data
├── Pulse Shapes/
│   ├── Individual Pulse-shape files
│   └── Data for all pulse-shapes
└── Spectra/
    ├── Radiation spectra from LSP
    ├── Calibration spectra
    └── Database of atomic line emissions used for analysis
```

### Naming convention
Each LSP test is identified by a unique ID of the following format:

`LSP[Index]_[Series][SeriesIndex]`

- `Index` is a unique numerical index incrementing by one for each subsequent successful LSP test (with successful ignition)
- `Series` is an alphabetic code to group shots within a series---shots with similar parameters or the same goal
- `SeriesIndex` is the index of the shot within a given series

For example,  `LSP53_S3` is the *53rd* LSP test and the *third* test in the `S` series (studying LSP spectral emission). `LSP30_PS24` is the *30th* test and the *24th* in the the `PS` series (studying power threshold).

All data associated with a given shot will be identified with the same identifier, either pre-fixing the relevant subdirectory (for ~~high-speed footage and~~ pressure data) or the file itself (for spectral data) accordingly. For instance, `LSP63_S12` has ~~footage~~, spectral data, and pressure data found in the following locations:
```
.
├── LSP/
│   └── NO LSP FOOTAGE AVAILABLE IN THIS VERSION
├── Pressure Data/
│   └── LSP63_S12/
│       ├── WaveData12521.csv   # Laser emission signal
│       └── WaveData12522.csv   # Pressure signal
└── Spectra/
    └── LSP63_S12_Subt4_17-13-28-762.txt    # Spectrogram
```

Note that some shots were done before the naming convention was adopted. These were retroactively assigned indices 200 and above, and are all part of the `SPX` series of shots. Please refer to `LSP/README.md` and `LSP/shotlist.xlsx` for further information. Pressure data and spectra were not collected for these shots.


## Methodological information
Please refer to the data groups' respective READMEs for information on methodology.


## Data-specific information
Please refer to the data groups' respective READMEs for data-specific information.


## Sharing and access information
All the data is shared under a CC BY 4.0 license. Please provide proper attribution by citing the dataset with your preferred citation style. For example:

Duplay, Emmanuel, Gabriel Dubé, and Siera Riel. “Argon Laser-Sustained Plasma Footage, Pressure Data, and Spectral Data.” 4TU.ResearchData, 2023. https://doi.org/10.4121/04ad8110-e3c4-4971-99ce-8a6c537166d6.


## Contact
Emmanuel Duplay  
emmanuel.duplay@gmail.com