# Argon Laser-Sustained Plasma Spectral Data
Authors: Emmanuel Duplay, Gabriel Dubé, Siera Riel

This dataset is related to the following Master's thesis:

Duplay, Emmanuel. “Argon Laser-Plasma Thruster - Design and Test of a Laboratory Model.” M.Sc. Thesis, Delft University of Technology, 2024.


## Introduction
This group of data contains the spectra of the radiation emitted by the LSP. Each spectrum is prefixed with a unique LSP test identifier that can be referenced to the `../LSP/shotlist.xlsx` test spreadsheet.


## Methodological information
These spectra were captured using an Ocean Optics (now Ocean Insight) USB4000 portable USB spectrometer. The spectral data was saved as whitespace-separated tabular data, exported by the free OceanView Lite software published by Ocean Insight. These spectra were processed by the software to remove background radiation with the "Create dark background spectrum" feature.

All files report a detected radiation intensity at a given wavelength. However, wavelength calibration must be performed to ensure the detected wavelength lines up with the real wavelength of the light. This can be performed with the `calibration/HgAr_pixel.csv` file and the `spectrum.py` module in the code associated with this project.

Relative intensity calibration must also be performed, again through `spectrum.py` and using the `Halogen_Light.txt` and `Halogen_Dark.txt` files contained in the `calibration` directory.

More details on calibration can be found in the documentation of the code associated with this thesis and data.


## Data-specific information
All spectral data files contain 12 lines of metadata and use the following format:
- **Column 1**: Wavelength in nm
- **Column 2**: Signal intensity in arbitrary units.

The `calibration/HgAr_pixel.csv` file contains calibration coefficients of wavelength calibration. These are handled by the `spectrum.py` module.

The `transitiondb/ArItransitions.csv` file contains data retrieved from the NIST Atomic Spectra Database used for temperature estimation by the Boltzmann plot method. This file is used by the processing code.


## Sharing and access information
All the data is shared under a CC BY 4.0 license. Please provide proper attribution by citing the dataset with your preferred citation style. For example:

Duplay, Emmanuel, Gabriel Dubé, and Siera Riel. “Argon Laser-Sustained Plasma Footage, Pressure Data, and Spectral Data.” 4TU.ResearchData, 2023. https://doi.org/10.4121/04ad8110-e3c4-4971-99ce-8a6c537166d6.


## Contact
Emmanuel Duplay  
emmanuel.duplay@gmail.com